unit eBob42.DBSpinEdit;
interface
uses
  SysUtils, Classes, Controls, StdCtrls, Spin,
  DB, DBCtrls;

type
  IDataAware = interface
    function GetDataSource: TDataSource;
    procedure SetDataSource(const Value: TDataSource);
    function GetDataField: string;
    procedure SetDataField(const Value: string);
    property DataSource: TDataSource read GetDataSource write SetDataSource;
    property DataField: String read GetDataField write SetDataField;
  end;

type
  TDBSpinEdit = class(TSpinEdit, IDataAware)
  private
    { Private declarations }
    FFieldDataLink: TFieldDataLink;
    function GetDataField: String;
    function GetDataSource: TDataSource;
    procedure SetDataField(const Value: String);
    procedure SetDataSource(const Value: TDataSource);
  protected
    procedure Change; override;
    { Protected declarations }
    procedure DataChange(Sender: TObject);
  public
    destructor Destroy; override;
    constructor Create(AOwner: TComponent); override;
    { Public declarations }
  published
    { Published declarations }
    property DataSource: TDataSource read GetDataSource write SetDataSource;
    property Whatever: TDataSource read GetDataSource write SetDataSource;
    property DataField: String read GetDataField write SetDataField;
    property FieldName: String read GetDataField write SetDataField;
  end;

implementation

{ TDBSpinEdit }

procedure TDBSpinEdit.Change;
begin
  inherited;
  Enabled := Assigned(FFieldDataLink);
  if Enabled then
    if Assigned(FFieldDataLink.Field) then
    begin
      if not (FFieldDataLink.Field.DataSet.State in [dsEdit, dsInsert]) then
        FFIeldDataLink.Field.DataSet.Edit;
      FFieldDataLink.Field.AsInteger := Value
    end
end;

constructor TDBSpinEdit.Create(AOwner: TComponent);
begin
  inherited;
  FFieldDataLink := TFieldDataLink.Create;
  FFieldDataLink.OnDataChange := DataChange
end;

procedure TDBSpinEdit.DataChange(Sender: TObject);
begin
  Enabled := Assigned(FFieldDataLink);
  if Enabled then
    if Assigned(FFieldDataLink.Field) then
      Value := StrToIntDef(FFieldDataLink.Field.AsString,0)
    {
    try
      Value := FFieldDataLink.Field.AsInteger
    except
      on E: EConvertError do
      begin
        Hint := E.Message;
        Value := 0
      end
    end
    }
    else Value := 0
  else Value := 0
end;

destructor TDBSpinEdit.Destroy;
begin
  FFieldDataLink.Free;
  inherited
end;

function TDBSpinEdit.GetDataField: String;
begin
  Result := FFieldDataLink.FieldName
end;

function TDBSpinEdit.GetDataSource: TDataSource;
begin
  Result := FFieldDataLink.DataSource
end;

procedure TDBSpinEdit.SetDataField(const Value: String);
begin
  FFieldDataLink.FieldName := Value
end;

procedure TDBSpinEdit.SetDataSource(const Value: TDataSource);
begin
  FFieldDataLink.DataSource := Value
end;

end.
